@@ -17,7 +17,7 @@
  *          Matthew Saltzman, Clemson University                             *
  *                                                                           * 
  *                                                                           *
- * Copyright (C) 2001-2011, Lehigh University, Yan Xu, and Ted Ralphs.       *
+ * Copyright (C) 2001-2013, Lehigh University, Yan Xu, and Ted Ralphs.       *
  *===========================================================================*/
 
 #include "iomanip"
@@ -56,7 +56,7 @@ AlpsKnowledgeBrokerSerial::initializeSearch(int argc,
     
     if (msgLevel_ > 0) {
 	std::cout << "==  Welcome to the Abstract Library for Parallel Search (ALPS) \n";
-	std::cout << "==  Copyright 2000-2011 Lehigh University and others \n";
+	std::cout << "==  Copyright 2000-2013 Lehigh University and others \n";
 	    std::cout << "==  All Rights Reserved. \n";
 	    std::cout << "==  Distributed under the Eclipse Public License 1.0 \n";
 	    if (strcmp(ALPS_VERSION, "trunk")){
@@ -297,10 +297,15 @@ AlpsKnowledgeBrokerSerial::searchLog()
 	    messageHandler()->message(ALPS_S_FINAL_NO_SOL, messages())
 		<< CoinMessageEol;
 	}
-	messageHandler()->message(ALPS_S_FINAL_NODE_PROCESSED, messages())
-	    << nodeProcessedNum_ << CoinMessageEol;
-	messageHandler()->message(ALPS_S_FINAL_NODE_PARTIAL, messages())
-	    << nodePartialNum_ << CoinMessageEol;
+	if (nodePartialNum_){
+	   messageHandler()->message(ALPS_S_FINAL_NODE_FULL, messages())
+	      << nodeProcessedNum_ << CoinMessageEol;
+	   messageHandler()->message(ALPS_S_FINAL_NODE_PARTIAL, messages())
+	      << nodePartialNum_ << CoinMessageEol;
+	}else{
+	   messageHandler()->message(ALPS_S_FINAL_NODE_PROCESSED, messages())
+	      << nodeProcessedNum_ << CoinMessageEol;
+	}
 	messageHandler()->message(ALPS_S_FINAL_NODE_BRANCHED, messages())
 	    << nodeBranchedNum_ << CoinMessageEol;
 	messageHandler()->message(ALPS_S_FINAL_NODE_DISCARDED, messages())
@@ -339,6 +344,7 @@ AlpsKnowledgeBrokerSerial::searchLog()
 	fout << "Number of nodes processed = "<<nodeProcessedNum_ << std::endl;
 	fout << "Number of nodes partially processed = "<<nodePartialNum_<<std::endl;
 	fout << "Number of nodes branched = "<<nodeBranchedNum_ << std::endl;
+	fout << "Number of nodes discarded = "<<nodeDiscardedNum_ << std::endl;
 	fout << "Number of nodes left in queue= " << nodeLeftNum_ << std::endl;
 	fout << "Tree depth = " << treeDepth_ << std::endl;
 	
